from __future__ import division
from scipy.misc import comb
from scipy.stats import norm
from math import sqrt

def ballcombs(n, k, m):
    return sum([(-1)**i * comb(k, i, exact=True) *
                          comb(n + k - 1 - i * (m + 1), k-1, exact=True)
                for i in range(k+1)])

def pdf_balltest(n, k, m):
    return ballcombs(n, k, m) / (m+1)**k

def cdf_balltest(n, k, m, exact=True):
    if exact:
        combs = sum([ballcombs(i, k, m) for i in range(n+1)])
        return combs / (m+1)**k
    else:
        valmean = m / 2
        variance = ((m+1)**2 - 1 )/12
        
        # Normalize as per Central Limit Theorem
        demeaned = n - k*valmean
        normalized = demeaned / sqrt(variance * k)
        
        # ... in order to obtain a standard normal:
        return norm.cdf(normalized)


